@@ -8,22 +8,22 @@ use Math::BigInt::Lib 1.999801;
 
 our @ISA = qw< Math::BigInt::Lib >;
 
-our $VERSION = '0.0013';
+our $VERSION = '0.0014';
 
 use Math::GMPz 0.36 qw< :mpz >;
 
-###############################################################################
-# It might be that Math::GMPz was built with an newer version of GMP than the
-# one that is currently available. Checking Math::GMPz::gmp_v() won't help,
-# since it returns the version of GMP used when Math::GMPz was built, not the
-# version of GMP that is currently available.
+BEGIN {
+    # We need GMP 5.1.0 or newer for Rmpz_2fac_ui(). If Rmpz_2fac_ui() is not
+    # implemented, Math::GMPz dies with the message:
+    # "Rmpz_2fac_ui not implemented - gmp-5.1.0 (or later) is needed"
 
-eval { my $x = Rmpz_init(); Rmpz_2fac_ui($x, 0); };
-
-# If Rmpz_2fac_ui() is not implemented, Math::GMPz dies with the message:
-# "Rmpz_2fac_ui not implemented - gmp-5.1.0 (or later) is needed"
-
-die "gmp-5.1.0 (or later) is needed" if $@;
+    my $gmp_v = Math::GMPz::gmp_v();
+    my @gmp_v = split /\./, $gmp_v;
+    my $gmp_v_int = 1e6 * $gmp_v[0] + 1e3 * $gmp_v[1] + $gmp_v[0];
+    die "GMP library is not recent enough;",
+      " we have $gmp_v, but we need 5.1.0 or later"
+      unless $gmp_v_int >= 5_100_000;
+}
 
 ###############################################################################
 
@@ -229,7 +229,57 @@ sub _lsft {
     return $_[1];
 }
 
-#sub _log_int { }
+sub _log_int {
+    my ($class, $x, $b) = @_;
+
+    # Return undef for the logarithm of zero.
+
+    return if $class -> _is_zero($x);
+
+    # Rmpz_sizeinbase() requires that the base is <= 62.
+
+    my $bscl;                   # the base as a Perl scalar
+    if (ref $b) {
+        $bscl = $class -> _num($b);
+    }  else {
+        ($bscl, $b) = ($b, $class -> _new($b));
+    }
+
+    return                                   if $bscl < 2;
+    return $class -> SUPER::_log_int($x, $b) if $bscl > 62;
+
+    # Rmpz_sizeinbase() returns a Perl scalar that is either 1 or 2 too big
+    # compared to the output we want, i.e., int(log(x) / log(b)).
+
+    my $y = Rmpz_sizeinbase($x, $bscl);
+    $y = $class -> _new($y - 1);
+
+    # To determine whether we need to subtract one more, we need to go
+    # backwards and compute $b ** $y, unfortunately.
+
+    my $trial = $class -> _pow($class -> _copy($b), $y);
+    my $acmp  = $class -> _acmp($trial, $x);
+
+    # Did we get the exact result?
+
+    if ($acmp == 0) {
+        return $y, 1 if wantarray;
+        return $y;
+    }
+
+    # Decrement $y once more, if the output was too large.
+
+    $y = $class -> _dec($y) if $acmp > 0;
+    return $y unless wantarray;
+
+    # If the user wants to know whether the output is exact or not, we need to
+    # update $acmp after the decrement above.
+
+    $trial = $class -> _div($trial, $b);
+    $acmp  = $class -> _acmp($trial, $x);
+    return $y, 1 if $acmp == 0;         # result is exact
+    return $y, 0;                       # result is too small
+}
 
 sub _gcd {
     Rmpz_gcd($_[1], $_[1], $_[2]);
@@ -515,6 +565,8 @@ The following methods are implemented.
 
 =item _lsft()
 
+=item _log_int()
+
 =item _gcd()
 
 =item _lcm()
